==> google-cloud-documentai-0.2.0.tar.gz: google-cloud-documentai-0.2.0/google/cloud/documentai_v1beta2/types/__init__.py <==
# -*- coding: utf-8 -*-

# Copyright 2020 Google LLC
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#

from .geometry import Vertex, NormalizedVertex, BoundingPoly
from .document import Document
from .document_understanding import (
    BatchProcessDocumentsRequest,
    ProcessDocumentRequest,
    BatchProcessDocumentsResponse,
    ProcessDocumentResponse,
    OcrParams,
    TableExtractionParams,
    TableBoundHint,
    FormExtractionParams,
    KeyValuePairHint,
    EntityExtractionParams,
    AutoMlParams,
    InputConfig,
    OutputConfig,
    GcsSource,
    GcsDestination,
    OperationMetadata,
)


__all__ = (
    "Vertex",
    "NormalizedVertex",
    "BoundingPoly",
    "Document",
    "BatchProcessDocumentsRequest",
    "ProcessDocumentRequest",
    "BatchProcessDocumentsResponse",
    "ProcessDocumentResponse",
    "OcrParams",
    "TableExtractionParams",
    "TableBoundHint",
    "FormExtractionParams",
    "KeyValuePairHint",
    "EntityExtractionParams",
    "AutoMlParams",
    "InputConfig",
    "OutputConfig",
    "GcsSource",
    "GcsDestination",
    "OperationMetadata",
)

==> google-cloud-documentai-0.3.0.tar.gz: google-cloud-documentai-0.3.0/google/cloud/documentai_v1beta2/types/__init__.py <==
# -*- coding: utf-8 -*-

# Copyright 2020 Google LLC
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#

from .geometry import (
    Vertex,
    NormalizedVertex,
    BoundingPoly,
)
from .document import Document
from .document_understanding import (
    BatchProcessDocumentsRequest,
    ProcessDocumentRequest,
    BatchProcessDocumentsResponse,
    ProcessDocumentResponse,
    OcrParams,
    TableExtractionParams,
    TableBoundHint,
    FormExtractionParams,
    KeyValuePairHint,
    EntityExtractionParams,
    AutoMlParams,
    InputConfig,
    OutputConfig,
    GcsSource,
    GcsDestination,
    OperationMetadata,
)


__all__ = (
    "Vertex",
    "NormalizedVertex",
    "BoundingPoly",
    "Document",
    "BatchProcessDocumentsRequest",
    "ProcessDocumentRequest",
    "BatchProcessDocumentsResponse",
    "ProcessDocumentResponse",
    "OcrParams",
    "TableExtractionParams",
    "TableBoundHint",
    "FormExtractionParams",
    "KeyValuePairHint",
    "EntityExtractionParams",
    "AutoMlParams",
    "InputConfig",
    "OutputConfig",
    "GcsSource",
    "GcsDestination",
    "OperationMetadata",
)
